
# q-expansion of newform 2014.2.a.g, downloaded from the LMFDB on 08 June 2024.

# We generate the q-expansion using the Hecke eigenvalues a_p at the primes.
# Each a_p is given as a linear combination
# of the following basis for the coefficient ring.

def make_data():

    from sage.all import prod, floor, prime_powers, gcd, QQ, primes_first_n, next_prime, RR

    def discrete_log(elts, gens, mod):
        # algorithm 2.2, page 16 of https://arxiv.org/abs/0903.2785
        def table_gens(gens, mod):
            T = [1]
            n = len(gens)
            r = [None]*n
            s = [None]*n
            for i in range(n):
                beta = gens[i]
                r[i] = 1
                N = len(T)
                while beta not in T:
                    for Tj in T[:N]:
                        T.append((beta*Tj) % mod)
                    beta = (beta*gens[i]) % mod
                    r[i] += 1
                s[i] = T.index(beta)
            return T, r, s
        T, r, s = table_gens(gens, mod)
        n = len(gens)
        N = [ prod(r[:j]) for j in range(n) ]
        Z = lambda s: [ (floor(s/N[j]) % r[j]) for j in range(n)]
        return [Z(T.index(elt % mod)) for elt in elts]
    def extend_multiplicatively(an):
        for pp in prime_powers(len(an)-1):
            for k in range(1, (len(an) - 1)//pp + 1):
                if gcd(k, pp) == 1:
                    an[pp*k] = an[pp]*an[k]
    from sage.all import PolynomialRing, NumberField, ZZ
    R = PolynomialRing(QQ, "x")
    f = R(poly_data)
    K = NumberField(f, "a")
    betas = [K([c/ZZ(den) for c in num]) for num, den in basis_data]
    convert_elt_to_field = lambda elt: sum(c*beta for c, beta in zip(elt, betas))
    # convert aps to K elements
    primes = primes_first_n(len(aps_data))
    good_primes = [p for p in primes if not p.divides(level)]
    aps = map(convert_elt_to_field, aps_data)
    if not hecke_ring_character_values:
        # trivial character
        char_values = dict(zip(good_primes, [1]*len(good_primes)))
    else:
        gens = [elt[0] for elt in hecke_ring_character_values]
        gens_values = [convert_elt_to_field(elt[1]) for elt in hecke_ring_character_values]
        char_values = dict([(
            p,prod(g**k for g, k in zip(gens_values, elt)))
            for p, elt in zip(good_primes, discrete_log(good_primes, gens, level))
            ])
    an_list_bound = next_prime(primes[-1])
    an = [0]*an_list_bound
    an[1] = 1
    
    from sage.all import PowerSeriesRing
    PS = PowerSeriesRing(K, "q")
    for p, ap in zip(primes, aps):
        if p.divides(level):
            euler_factor = [1, -ap]
        else:
            euler_factor = [1, -ap, p**(weight - 1) * char_values[p]]
        k = RR(an_list_bound).log(p).floor() + 1
        foo = (1/PS(euler_factor)).padded_list(k)
        for i in range(1, k):
            an[p**i] = foo[i]
    extend_multiplicatively(an)
    return PS(an)
level = 2014
weight = 2
poly_data = [-10, -52, -61, 21, 50, -1, -13, 0, 1]

# The entries in the following list give a basis for the
# coefficient ring in terms of a root of the defining polynomial above.
# Each line consists of the coefficients of the numerator, and a denominator.
basis_data  = [[[1, 0, 0, 0, 0, 0, 0, 0], 1], [[0, 1, 0, 0, 0, 0, 0, 0], 1], [[6, 20, 1, -10, 0, 1, 0, 0], 1], [[-9, -20, 0, 10, 0, -1, 0, 0], 1], [[-4, 4, 21, 1, -10, 0, 1, 0], 1], [[-7, -29, -16, 30, 11, -11, -1, 1], 1], [[9, 43, 18, -39, -11, 12, 1, -1], 1], [[18, 46, 10, -39, -10, 12, 1, -1], 1]]

hecke_ring_character_values = None
aps_data = [[-1, 0, 0, 0, 0, 0, 0, 0], [0, -1, 0, 0, 0, 0, 0, 0], [0, 0, 0, 0, 0, -1, 0, 0], [0, 0, 0, 0, -1, 0, 0, 0], [0, 0, 0, 0, 0, 0, -1, -1], [-1, 0, 0, 0, 0, 1, 0, 1], [-1, 1, 0, -1, 0, -1, 0, -1], [-1, 0, 0, 0, 0, 0, 0, 0], [0, 2, -1, -1, 2, 1, 1, 0], [-2, 1, -1, 0, 1, 1, -1, 0], [-1, 1, -2, -2, 1, 2, 2, 1], [0, -2, 1, 0, 1, 1, -1, 0], [0, 1, -1, 2, 0, 1, 1, 1], [1, 0, 1, 1, -1, 1, 0, 0], [-2, 1, 1, 0, 1, -1, -1, 0], [-1, 0, 0, 0, 0, 0, 0, 0], [-2, 1, 1, 0, 1, 1, 2, 0], [0, 0, 1, 2, -2, 0, 0, 0], [1, 3, 1, 2, 1, -1, 0, 0], [-5, -4, 3, 1, -2, -1, -1, 0], [3, 2, -3, -1, 0, 3, -1, -1], [0, 0, 3, 0, 0, -3, 0, 1], [0, 4, -1, -1, 2, -1, 2, 2], [-8, -3, 3, -1, -1, -3, -1, 2], [-2, -2, -1, 0, 2, -2, -3, 0], [-1, -2, 1, -1, 0, 1, 2, 0], [3, -3, 0, 4, -2, -1, 0, -2], [-3, -2, -3, -1, -1, -3, -1, 1], [-1, 1, 0, 1, -3, 0, 1, -2], [-3, -1, -1, -2, 2, 1, -3, 0], [0, 0, 3, 6, -3, -1, 0, 0], [-4, 3, -2, -3, 2, 3, 0, 3], [-2, 1, -3, 1, 2, 4, 5, 1], [0, 0, -3, -3, 3, 3, 0, 2], [-7, -3, 0, 0, -2, -2, -1, 0], [1, -1, 0, -2, 2, 1, -2, -1], [2, -3, 0, -1, 2, 4, 2, 0], [4, 2, -1, 2, 1, -2, 1, -2], [-4, -5, 3, 3, -4, -4, 0, 1], [-2, 1, 4, 0, 0, 1, -2, -2], [-2, -1, 2, 2, -5, -1, 3, -2], [-4, 0, -3, -2, 2, 0, 2, -2], [-4, -2, -5, -1, 3, -1, 1, 2], [-2, -3, 6, 1, -4, -5, -2, -1], [1, 0, 4, 1, -2, 1, 1, 0], [1, 1, -2, -1, 3, -3, -1, -3], [-3, 3, 1, 7, -2, -1, 6, 2], [-1, -5, 5, -4, 1, 1, -4, 1], [2, 2, -3, 4, 2, 5, 5, 1], [-2, 0, -3, 1, -6, -4, 5, -4], [0, 1, -3, -4, -1, 3, -3, 0], [-7, 4, -3, 0, 1, 2, -2, 1], [-11, -4, 1, 1, -4, -3, 0, 0], [-2, 4, -2, 0, -2, -2, 2, 0], [-3, 0, 1, -3, 2, 0, -4, -1], [0, 4, 0, -1, -3, -2, -2, 1], [2, 0, 3, 2, -1, -4, -6, -2], [5, -4, -2, 1, 3, 1, -3, -4], [-2, 3, 2, 1, 2, -7, 1, -1], [-3, -2, 2, 1, 1, 0, 3, 4], [9, 4, -2, 4, -4, 3, 4, -1], [-3, 2, -2, 1, 2, 5, 7, 4], [4, -5, 3, 2, -5, -7, -4, -4], [4, 3, -7, -5, 4, 6, -1, 5], [4, 0, -2, 0, 3, 3, 3, 1], [-13, 1, -2, -1, 2, 2, 4, 4], [6, -3, -2, -5, 2, 3, 0, 0], [-2, 2, -5, -2, -2, 4, 8, -1], [3, 1, -4, -4, -2, 2, -2, 0], [4, 5, -4, -5, 1, 2, -6, 1], [-4, 1, 6, 0, -1, -9, 1, 0], [5, 2, -2, -4, -5, 0, -4, -3], [4, -4, -1, 5, -1, 2, 3, 2], [-4, -3, -5, -4, 3, 2, -5, -1], [1, -3, 3, -4, -4, 1, 0, 1], [8, 1, -1, -3, 1, -2, -8, -6], [-6, -10, 2, -2, -2, -2, -5, 1], [13, 3, 2, 2, 1, -4, 0, 2], [4, 2, 1, 2, 6, 9, 1, -1], [4, 1, 4, 9, -1, 4, 2, -1], [4, -8, 4, 4, -4, 4, -4, -3], [10, -2, -1, 1, -1, -6, -4, -4], [-6, 4, 0, -4, 2, 2, 2, -3], [4, 8, -13, 0, 5, 8, 6, -1], [4, 6, 0, -2, 1, 2, 0, 2], [3, -5, -1, -6, 5, -3, -6, 3], [-8, -4, 7, 0, -2, 1, -1, -2], [3, -11, -1, -1, 1, -1, -7, 1], [10, -6, 3, -3, 4, 0, -5, -3], [14, 7, -1, 0, 0, -2, 3, 0], [-12, -2, 2, -6, -2, -3, 1, 4], [-2, -1, 5, 3, -1, 5, 4, -2], [2, -4, 0, 11, 1, 3, -2, -1], [-4, -4, 9, -5, -3, -2, -3, 0], [4, -7, -2, -3, 3, -6, -1, 3], [14, 2, -1, 2, -6, -1, 3, -2], [4, 13, -9, -1, 4, 5, 2, 2], [4, -5, -13, -5, 3, 6, 6, 0], [6, -2, -1, 3, -5, 7, -3, 1], [3, -1, -1, -1, -7, -1, 5, -2], [8, -1, 0, 1, 0, 9, 2, 5], [-7, -3, -3, -6, -4, 0, 4, 0], [-7, -7, 3, -5, 0, -6, 0, 3], [-6, 7, -6, -4, 4, 1, -1, 5], [-4, -1, -9, -13, 3, -1, 4, 4], [5, -5, 10, 3, -4, -2, -5, -5], [21, 1, 2, 4, 1, -4, -4, -4], [-3, 6, -6, 5, 0, 9, 3, -2], [-10, 0, 0, 3, 2, -2, 3, 1], [-11, -9, 11, 4, -3, -3, -4, 5], [6, -5, 1, 6, -1, 6, -6, -2], [-2, -1, -1, -7, -6, -10, 4, 1], [0, 3, -8, -2, 1, 4, -4, -5], [6, 8, -5, 0, 2, 3, 6, 1], [5, -9, -5, -4, 0, 5, -8, 2], [-6, 1, -5, -8, 1, -2, -6, -5], [13, 0, -2, 3, -4, 4, -3, -5], [-2, -4, 1, 2, -10, -2, 4, 2], [9, 2, 1, 0, -8, -3, 6, -2], [-19, -1, 3, -2, -1, -1, -2, -4], [4, -1, 6, 3, 2, -11, -8, -9], [0, -7, 2, 7, -6, -10, -4, -2], [6, -12, 11, 4, -8, -9, -13, -6], [0, 13, -6, -2, 6, 3, 10, 3], [-2, 0, 5, 2, 5, 2, -8, 2], [2, -6, 8, 6, -5, -4, -4, -10], [1, -4, -8, 1, 2, 6, 7, -3], [-7, 4, -7, 3, 2, 6, 2, 4], [19, 8, -10, -3, 0, 7, 1, -1], [10, 7, -14, -7, 7, 9, 6, -1], [-2, -2, 4, 1, 2, -1, 0, 4], [0, -16, 4, 1, -10, 1, -2, -2], [-13, -5, 10, 1, -1, -7, -7, 2], [-2, 13, -7, -1, 9, -7, 4, -1], [-11, -8, 0, 8, 2, 8, 3, 0], [-16, 1, 2, -10, 2, -11, 5, 4], [-8, 8, -5, 3, 0, 8, 0, 0], [-7, -7, 8, -5, 3, -14, 2, 8], [-5, 4, 2, 0, -1, -4, -2, -7], [-15, 5, 4, 11, -6, -3, -5, -3], [-6, 5, 8, 4, -1, -8, -9, -9], [12, 12, -5, -4, 6, -3, 2, 5], [-18, 5, 2, -9, 6, -3, 2, 0], [-6, -2, 20, 5, -2, -6, -7, -1], [-4, -3, 4, 2, -3, 7, 4, -1], [10, -4, 12, 3, -1, -15, -4, 1], [19, 4, -2, -3, 10, 2, -4, 5], [-25, -6, 4, 1, 4, -3, -6, 0], [-8, -6, -3, 4, -5, -11, -4, 0], [1, -14, 5, -3, 2, -9, -9, 1], [-3, -3, 11, 3, -5, -13, -3, 2], [12, 9, -8, 1, -6, 2, 5, -5], [-4, 0, -1, 3, 2, 11, 6, 1], [-11, 11, 7, 14, -4, -4, 8, 2], [-4, -2, -6, -1, 3, -3, -5, 1], [-16, -6, 1, 6, -4, -12, -2, 0], [13, 0, -3, 2, 3, 11, -1, 0], [-4, 0, 12, 9, -7, -6, -4, -7], [-10, 3, 2, -2, -1, 4, -1, -4], [-10, 1, -4, 0, -4, 0, -2, 2], [3, 6, -2, 5, -3, 0, 12, 2], [-18, 0, 4, 4, -10, -3, 1, -1], [-5, -5, -6, -3, -2, 1, 7, 4], [-11, 1, -8, -3, -1, 5, -4, 6], [-12, -3, -8, 1, 0, 7, -8, -3], [1, -13, -1, -5, 2, 2, 0, 1], [-4, 0, -5, 3, -4, -8, -1, 0], [-19, 1, 7, 7, -14, -9, -1, -3], [-14, 4, -3, -8, 1, -2, 4, 0], [0, 0, 3, 1, 11, 5, 8, 0], [-13, 5, -3, 1, 8, 12, 16, 3], [-8, 1, 11, -3, -10, -11, -8, -4], [17, -4, 5, 3, 1, 3, -5, 2], [14, 6, -2, -7, -6, -9, 2, -3], [-14, -4, 15, 2, -8, -11, -8, -9], [-10, -9, 2, -7, 4, 5, 4, 3], [-1, 0, -10, -17, 4, 2, 3, -5], [9, 5, -14, -2, 12, 13, 8, 6], [21, 12, -3, -1, 1, -6, 3, 3], [-14, -5, 15, 6, 0, -7, -5, 5], [6, -10, 1, 7, -2, -6, 4, -6], [14, 8, -2, -4, 5, 2, -6, -10], [1, -16, 14, 4, -15, -6, -2, 2], [-13, -5, 9, -2, 3, -2, -4, -7], [-10, 2, -1, 2, -2, 9, -1, -6], [3, -9, 9, 16, -8, -10, -17, -8], [7, 1, -6, -4, 0, 7, 6, 0], [-12, 8, -2, -12, 3, 9, -3, 5], [-3, 8, -3, 7, -8, 6, 9, 4], [3, -6, -8, -5, 0, 20, -2, 3], [-20, 12, -2, -4, 4, 5, 5, 9], [13, 1, -5, 6, 10, 1, 4, 2], [1, -10, 2, 0, -5, 0, -1, 4], [6, 6, -7, -6, 2, 14, 8, 6], [-22, 12, -5, -2, -2, 10, 6, 8], [-5, -11, 7, 1, -6, 1, -11, 1], [-18, 9, -11, -3, 10, 5, 0, 4], [-8, 16, 2, 2, 6, 3, 7, 6], [3, -1, 5, 1, 1, -2, -2, 1], [16, -6, -2, -7, 10, 4, 3, 5], [-28, 10, -5, -3, 3, 12, 11, 11], [1, 7, 11, 6, -2, -14, 8, -2], [-3, -1, 2, 13, -9, -6, 5, -6], [-12, 9, 0, 4, -1, -11, 3, 2], [1, 0, 13, 3, -3, -18, -17, -1], [7, 7, -9, -12, 11, 9, 6, -5], [-19, 2, 7, -4, 8, 3, -2, 7], [2, -7, -6, -10, 2, 1, 6, 2], [-19, -18, 18, 0, -3, -14, -8, 7], [-6, 2, -6, -3, -8, 0, -5, -6], [-7, 3, -5, -5, -7, -7, -2, -7], [3, 0, 15, -1, -4, -7, -5, -2], [16, -15, 3, -5, 6, 4, -9, -7], [-6, 0, -4, -4, -13, -7, 13, -1], [-6, -4, 0, 10, -8, -9, -13, -8], [-17, -15, 6, 8, 0, -8, -10, -1], [-13, -2, 2, 3, 9, 6, -6, 2], [-2, -9, 10, 15, -15, -2, 0, -6], [5, -11, 3, 7, -1, 5, 3, -4], [30, 0, -7, -10, 10, 2, -3, -4], [-11, 14, -11, -2, 5, 9, 13, 14], [-11, -4, 10, -1, 7, -8, -11, 2], [-19, 16, -8, 2, 3, 12, 7, 9], [25, -4, -9, -1, 5, 9, 7, 9], [-13, -3, 5, -1, 5, 5, 10, 0], [28, 9, -8, 9, 0, -6, 2, -3], [2, 6, 5, -5, -3, -5, 6, 4], [-24, 0, 6, 2, 0, -10, -1, -4], [-2, -6, -10, -7, 3, -2, -1, -3], [18, -4, 4, -1, 1, -9, -6, 7], [14, -11, 11, 15, -11, -6, -17, 1], [7, 11, 5, 7, 8, 4, -11, -6], [7, 26, -9, 1, 3, 4, 20, 1], [-7, 7, -1, -2, 1, -8, 13, 6], [-9, 7, -4, 4, -9, -7, 12, -2], [24, 10, 3, 4, 3, 2, 8, -1], [5, -7, -1, 1, -12, -1, -7, -6], [-1, 11, -6, -11, 1, 12, 8, 4], [8, 13, -10, -1, 11, 0, -2, -3], [13, 3, -6, -10, 10, 4, -9, -9], [0, -14, 3, -6, -1, -5, -11, -4], [4, -5, -7, 5, -3, -1, -1, 2], [-11, 1, 1, -8, 3, -10, 5, 2], [10, 12, -12, 1, 3, 8, 6, -3], [-3, 0, -8, -3, -8, -3, 6, -1], [-6, -9, -7, -12, 2, -5, -4, 2], [-12, -6, 7, 8, -6, -1, -11, -5], [-7, 6, -3, 5, 2, -9, 1, 2], [-13, 3, -2, -6, 2, -6, 3, -9], [10, 2, -10, 6, -10, -6, 2, -11], [-8, 8, -4, 0, 7, 6, 12, 9], [7, 6, -4, 8, 5, 9, 13, 9], [4, 2, 3, 5, -5, -6, 11, -9], [-14, 3, -4, -6, 2, 17, 15, 10], [23, -2, 0, -1, -9, 7, 1, 4], [0, 7, -8, 13, -4, 1, 9, -1], [-8, -3, 3, 9, -2, 7, 6, 1], [0, 1, -4, -5, 9, 2, 7, -1], [-10, 1, 8, -3, 2, -17, -2, -6], [-6, 2, 0, 4, -2, 13, 5, -1], [3, -1, -4, 2, 4, -3, -14, -2], [-6, 3, 0, 0, 11, 9, -8, 3], [11, 5, -6, -6, 1, 10, -12, -1], [-7, -13, 4, 5, -8, -4, -11, 6], [8, -4, 2, 8, 1, -5, -5, -5], [26, 2, 2, 2, 6, -9, -13, -6], [13, 1, 1, 10, 4, -1, 4, 8], [3, 2, 2, 7, -7, 10, 0, 0], [-1, 2, 0, 3, 1, -12, -4, 2], [-7, 14, 4, 6, 6, -4, 7, 3], [-17, 11, -6, -9, 8, -2, -5, 1], [18, -12, 19, 2, -13, -12, -18, -10], [24, -8, -3, 3, -13, 1, -9, 0], [-16, -12, -1, 3, -6, -5, 0, -7], [-29, 12, 1, 1, 8, 7, 7, 3], [-9, -18, 14, -2, -7, -7, 5, 9], [12, -23, -6, 1, -4, 10, -9, 4], [-13, 22, -1, -1, 11, -1, 5, 3], [-1, 16, -11, -7, 4, 17, -6, 2], [-17, -1, 8, 10, -14, -15, -3, -5], [-4, -3, 8, -1, -3, 9, -1, 9], [-7, 7, -10, -11, 2, 7, 17, 3], [15, 13, -5, -3, -3, -2, 5, 5], [7, -7, 6, -8, -4, -5, 2, -1], [-13, 1, -2, 5, -15, 1, 1, -8], [-24, 4, 2, -5, -13, -9, 10, 8], [14, 4, 8, 3, 3, -5, -10, 1], [1, 16, -17, -8, 6, 20, 14, 0], [19, -3, 7, -4, -4, 6, -5, 1], [25, 7, 10, 1, -7, 0, -14, -2], [7, 12, 8, -2, -3, 5, 4, -7], [-19, -3, 4, -14, 8, -7, 3, -3], [0, 1, 9, -5, -6, -9, 6, -12], [8, 9, 15, 14, -2, -11, 9, 2], [-6, -12, 7, 5, -3, -20, -1, -3], [-1, -5, 7, 4, -9, 1, -3, -8], [-24, 8, -9, -3, 10, -9, 2, -1], [0, 9, -13, -9, 9, 10, 7, 0], [-4, -14, 10, 9, 0, 7, 0, -6], [27, 14, 3, 2, -1, 2, 3, -1], [0, -5, 10, 14, 2, -8, 2, 0], [20, 1, 4, 17, 3, 6, -13, -5], [16, 4, 10, -1, -10, -12, -7, -1], [-1, -6, 16, 0, -2, -21, -9, 1], [-3, 7, -5, -4, -13, 2, -1, -1], [0, 4, -3, -3, -19, 2, -1, 0], [-18, 0, 21, 5, -7, -26, -10, 0], [2, 14, -12, -4, -7, 17, 19, 1], [-8, -8, 2, 3, -9, 3, 0, -2], [2, -11, 4, 5, 3, -17, -11, -4], [-2, 0, -21, -9, 4, 15, 0, -4], [-2, 4, -21, -14, 10, -2, -1, 3], [5, 6, -7, 13, -6, -6, 2, 0], [-2, -2, 11, -9, -8, -8, -12, -6], [8, 4, 3, 11, 5, 7, 9, 3], [6, -9, -4, 11, -1, 10, 11, 3], [-7, 8, -2, 7, 4, 10, -8, -5], [-5, -1, 10, 20, -7, 3, -4, 3], [15, 7, -8, -17, 14, 16, -1, 1], [-27, -2, 13, 4, -6, -10, -8, -6], [-13, -6, 11, -9, 9, 9, -9, 6], [-27, -2, 0, -3, 14, 0, 6, 3], [-11, 0, 3, -8, -7, -16, -10, -3], [18, 8, 5, 8, 6, -3, 8, 1], [13, 2, -7, -6, 9, 11, -14, -10], [-3, 8, 21, 2, -6, -3, -2, -1], [-1, 16, 3, -1, 13, -1, 5, 8], [2, -9, -10, -27, 6, 5, -12, -9], [-6, -10, 2, -12, 18, -9, 1, -1], [-3, 10, 9, 11, -11, 3, 5, -7], [16, -2, -21, -2, 5, 13, 12, 3], [-36, 4, 6, -5, 11, 0, -1, -5], [7, 8, -11, 1, -2, -4, -10, -15], [6, 5, -1, -3, -5, -1, 7, 7], [-22, -16, 11, 8, -2, -11, -18, -7], [23, -1, -12, 5, -9, 0, 8, 10], [-22, -24, 15, -9, -3, -12, -17, 3], [-6, 30, 2, -4, 1, 10, 12, -4], [-12, -19, 10, 8, -1, -5, -1, 5], [-20, 5, -11, 4, 10, 16, -7, 3], [-28, 7, 1, 3, -7, -3, -10, -11], [19, -9, -21, -12, 8, 10, 3, -7], [30, -10, 0, -5, -1, 1, 7, 0], [10, 9, -1, -5, 3, 8, 0, 13], [32, -12, 6, -1, -13, 2, -9, -3], [-5, 0, 9, 6, -4, -8, -14, -7], [-24, 1, -2, 2, -14, 0, 18, -7], [-26, -13, 16, 4, -12, 8, -1, 5], [-14, 8, -8, -6, -1, -2, 1, 2], [-15, -5, -12, 0, 5, 9, 20, 10], [10, -4, -9, -8, -6, -8, -4, -12], [-10, 0, -10, -9, 15, 1, -6, -8], [-9, -13, 2, -1, -12, -5, -7, 7], [-6, -1, 1, 3, -4, -6, 15, 6], [19, 7, -13, -12, 16, 11, -10, 6], [13, -5, -7, -7, -3, -17, -5, 0], [2, 29, -7, -5, 19, 9, 6, -1], [9, -14, 10, -1, -21, -9, -19, -15], [-11, -8, 23, 21, -10, -4, -2, 1], [3, -5, 2, -5, -19, -10, 2, -3], [-31, -12, 6, -5, -5, -9, -17, -3], [-2, 27, -12, -14, 14, 1, 17, 16], [-24, 3, 3, -1, -6, 11, -4, 2], [-9, -2, -11, 6, 7, 13, 16, 14], [-24, -21, 6, -5, -4, 10, -4, 9], [-23, 12, 9, 14, -2, 6, 7, -2], [-1, -12, 5, -9, -9, -4, -20, -8], [-12, -8, 4, -14, 2, -7, -5, -1], [-19, -5, -2, -1, 7, 2, 2, -4], [-19, -10, 3, 3, -6, 18, 15, 10], [-8, -9, 14, 17, -9, -14, 1, -4], [-29, -9, 11, 14, -1, -6, -11, -5], [8, 8, -12, -5, -3, 4, -6, -13], [-21, 19, -18, -11, 24, 10, 0, -3], [6, -15, 12, -13, 2, -20, -11, -2], [-26, -15, 15, -12, 6, -3, -9, 0], [-22, -2, 7, -2, 7, -9, -19, -10], [-15, 8, -10, -8, 7, 4, 10, 6], [-9, -8, 3, 5, -10, 16, -2, 13], [5, -7, 8, 11, -9, -8, -12, 5], [36, -10, -4, -2, -20, -6, 0, -4], [-1, -11, -24, -14, 5, 11, 12, -7], [0, 13, 5, 5, 4, 8, 13, 1], [13, -9, 6, 12, -15, -7, 14, -5], [-3, 3, -2, 12, -1, 12, -1, 8], [15, 3, 4, 10, -10, -4, -15, -12], [2, -5, 3, 10, 1, 10, 11, 1], [22, -6, -10, -2, 19, 12, 10, 18], [8, -5, 10, 8, 5, -4, -2, 12], [-10, 3, 15, 16, -4, -23, -15, -11], [4, 8, -7, 2, 10, 24, 28, 6], [-11, 18, -8, 8, -5, 1, 10, 9], [-14, -9, 10, 5, -1, 17, 2, 5], [8, -12, -12, 2, 6, 10, 16, -9], [22, -14, 13, 2, 2, 0, -7, -12], [-24, 8, 6, 4, 6, -2, 15, 11], [13, 3, -14, -12, 18, 1, 0, 0], [20, 11, -17, -22, 16, 19, -11, 0], [6, -7, 7, 13, -7, -8, 5, -11], [-8, 6, -6, -2, 13, 10, 6, -1], [1, -25, 1, 2, -1, 1, 6, -4], [11, -22, 17, -6, -2, -13, 4, -1], [-14, -7, -2, -2, 0, 3, -1, -12], [-37, 3, 5, 6, 10, -5, 4, 6], [10, 0, -4, -10, -2, -24, -8, -6], [-6, -2, 2, -12, 11, 2, -8, -9], [10, -3, -15, -11, 2, 26, -9, -6], [15, -19, 14, 9, -14, -20, -2, -7], [-23, 13, -12, -16, 10, 10, -3, 9], [-16, -18, 18, 16, -23, -5, -1, -16], [9, -13, 1, -16, 9, -9, 5, 0], [-7, -8, 28, 9, 0, -18, -24, -4], [4, -10, -5, 5, 11, 3, -14, 4], [-39, 3, -4, -2, 3, 15, 3, -6], [-23, -12, 15, 16, -18, -7, 4, 1], [1, -4, 17, 16, 0, -10, -5, -1], [0, 19, -5, 11, 4, -18, 3, -5], [14, -16, 10, 2, -15, -8, -12, -12], [-10, -17, 18, -8, -6, -13, -15, -4], [26, -2, -6, 0, 11, -4, -9, -9], [-15, 18, 1, -10, 11, 20, 3, 0], [-14, 5, -1, -10, 18, 0, 11, 1], [-7, 10, 5, 9, -2, -3, -13, 1], [16, 5, -11, -23, 13, 14, -17, -3], [10, -3, -9, -19, 2, -4, -16, -8], [-12, -1, 0, 4, -5, -2, 2, 11], [17, -11, -1, 6, 17, 18, -17, -9], [7, 15, -13, -17, 16, 17, 10, 17], [46, 18, -5, 4, 2, 6, 2, -8], [-6, -7, -7, 12, 11, 19, 2, -1]]
